﻿#---------------------------------------------------------------------------------------#
# Title:          Folder Search                                                         #
# Description:    Searches for Folders and sub folders and allows wildcard search       #
#                 Also, searches Hidden Folders - Output is in GridView                 #
# Author:         Anthony Constant                                                      #
#---------------------------------------------------------------------------------------#

# use case: Can't find a specific folder? Use this script to locate the specified folder. Once executed, the script will locate folders and subfolders and return the result.

Clear-Host

# clear terminal
cls

# Read user input
$folderPath = Read-Host "Enter folder path to locate*"  # Enter the file path you think the folder may be.
$folderName =  Read-Host "Enter folder name to locate*"    # Enter the keyword of the folder to locate it. (use * to use wildcard) 
Read-Host "Press Enter to begin searching for '$folderName' in '$folderPath' folder path" 

$output = Get-ChildItem -Force $folderPath -recurse | # Use -Force to locate hidden folders. (from $foldername variable) 
Where-Object {$_.PSIsContainer -eq $true -and $_.Name -like $folderName} | 
Select-Object FullName, LastWriteTime, Name | Sort-Object FullName ## Pull selected content from the search criteria

$count = ($output).Count
$output | Out-GridView -Title "Folder Directory Search Results - Total Count: $count" ## output the result in PS Gridview
Read-Host "Found '$count' results. Press Enter to end the script" 


